==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadGroupListFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WorkloadGroupListFluent<A extends WorkloadGroupListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,WorkloadGroup item);
  public A setToItems(Integer index,WorkloadGroup item);
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public A addAllToItems(Collection<WorkloadGroup> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public A removeAllFromItems(Collection<WorkloadGroup> items);
  public A removeMatchingFromItems(Predicate<WorkloadGroupBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadGroup> getItems();
  public List<WorkloadGroup> buildItems();
  public WorkloadGroup buildItem(Integer index);
  public WorkloadGroup buildFirstItem();
  public WorkloadGroup buildLastItem();
  public WorkloadGroup buildMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public A withItems(List<WorkloadGroup> items);
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public Boolean hasItems();
  public WorkloadGroupListFluent.ItemsNested<A> addNewItem();
  public WorkloadGroupListFluent.ItemsNested<A> addNewItemLike(WorkloadGroup item);
  public WorkloadGroupListFluent.ItemsNested<A> setNewItemLike(Integer index,WorkloadGroup item);
  public WorkloadGroupListFluent.ItemsNested<A> editItem(Integer index);
  public WorkloadGroupListFluent.ItemsNested<A> editFirstItem();
  public WorkloadGroupListFluent.ItemsNested<A> editLastItem();
  public WorkloadGroupListFluent.ItemsNested<A> editMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,WorkloadGroupFluent<WorkloadGroupListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadGroupListFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WorkloadGroupListFluent<A extends WorkloadGroupListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,WorkloadGroup item);
  public A setToItems(int index,WorkloadGroup item);
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public A addAllToItems(Collection<WorkloadGroup> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public A removeAllFromItems(Collection<WorkloadGroup> items);
  public A removeMatchingFromItems(Predicate<WorkloadGroupBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WorkloadGroup> getItems();
  public List<WorkloadGroup> buildItems();
  public WorkloadGroup buildItem(int index);
  public WorkloadGroup buildFirstItem();
  public WorkloadGroup buildLastItem();
  public WorkloadGroup buildMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public A withItems(List<WorkloadGroup> items);
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.WorkloadGroup... items);
  public Boolean hasItems();
  public WorkloadGroupListFluent.ItemsNested<A> addNewItem();
  public WorkloadGroupListFluent.ItemsNested<A> addNewItemLike(WorkloadGroup item);
  public WorkloadGroupListFluent.ItemsNested<A> setNewItemLike(int index,WorkloadGroup item);
  public WorkloadGroupListFluent.ItemsNested<A> editItem(int index);
  public WorkloadGroupListFluent.ItemsNested<A> editFirstItem();
  public WorkloadGroupListFluent.ItemsNested<A> editLastItem();
  public WorkloadGroupListFluent.ItemsNested<A> editMatchingItem(Predicate<WorkloadGroupBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,WorkloadGroupFluent<WorkloadGroupListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
